	subroutine define_DETEctor(mother)

c This routine defines the geometry and materials of the backscatter
c gamma and recoil electron detectors.
c Inputs:
c	name: 4-character name of outer volume
c
c PW 20-Oct-93
c  - original code
c
c Richard Jones June 20, 2003
c  - got rid of "fortran structure" references in favour of standard f77
c  - replaced trig intrinsics based on degrees (sind,cosd,tand..) with
c    local versions because g77 does not support them
c  - changed mixed-case names to upper-case for geant++ support
c  - This routine has been modified many times since the original version.
c    Some remnants of an early design based on a large crystal of hyper-
c    pure germanium still remain (hence the name hpge) surrounded by an
c    anti-coincidence shield, but most of that is no longer functional
c  - Added an electron detector in the form of silicon microstrips placed
c    downstream of the third dipole.

	implicit none

	include 'user.inc'
	include 'params.inc'
	include 'ugeom.inc'

	character*(*) mother			! volume to imbed this in
	integer foil_mate, col_mate, det_cover_mate, det_mate, volume_num
	integer det_dead_mate, recoil_mate
	integer side_mate, BaF_mate
	integer iset, idet
	integer material			! material number
	character*4 names(1)
	integer nbits(1)
	real orig(1),fact(1)
	data names/'Esum'/
	data nbits/32/
	data orig/0/
	data fact/1e9/
	real pars(9)


c Now define the foil

c	if (foil_thickness .gt. 0.) then
c	  call ugstmed (foil_mate, 'Foil$', int(foil_material + 0.5),
c	1		0, 0, FIELDM, TMAXFD, STEMAX, DEEMAX, EPSIL, 
c	2		STMIN, 0, 0)
c	  pars(1) = 0.
c	  pars(2) = 1.
c	  pars(3) = foil_thickness / 2.
c	  call ugsvolu ('FOIL', 'TUBE', foil_mate, pars, 3, volume_num)
c	  pars(3) = (chicane_length + foil_thickness) / 2. + dipole_length
c	  call gspos ('FOIL', 1,mother, 0., 0., pars(3), 0, 'ONLY')
c	  call gsatt ('FOIL', 'COLO', RED)	! Change color of the foil
c	  call gsatt ('FOIL', 'SEEN', 1)	! foil is visible
c	endif

c Now define the DETEctor

	call ugstmed (det_cover_mate, 'DETEctor$', int(hpge_cover_mate + 0.5),
	1	0, 0, FIELDM, TMAXFD, STEMAX, DEEMAX, EPSIL, STMIN, 0, 0)
	pars(1) =  0.0						! inner radius
	pars(2) =  hpge_diameter / 2. + hpge_cover_depth	! Outer radius
	pars(3) =  (hpge_depth + hpge_dead_depth) / 2. + hpge_cover_depth
	call ugsvolu ('DETE', 'TUBE ', det_cover_mate, pars, 3, volume_num)
	pars(1) = hpge_offset_x
	pars(2) = hpge_offset_y
	pars(3) = pars(3) + hpge_distance
	call gspos ('DETE', 1,mother, pars(1), pars(2), pars(3), 0, 'ONLY')
	call gsatt ('DETE', 'COLO', GREEN)	! Change color of the DETEctor
	call gsatt ('DETE', 'SEEN', 1)		! DETEctor is visible
	

c Now fill up the DETEctor with sensitive material

	material =  int(hpge_material)
	call ugstmed (det_mate, 'DETEctor$', material,
	1	1, 0, FIELDM, TMAXFD, STEMAX, DEEMAX, EPSIL, STMIN, 0, 0)

	pars(1) =  0.0
	pars(2) =  hpge_diameter / 2.
	pars(3) =  hpge_depth / 2.
	call ugsvolu ('DETI', 'TUBE ', det_mate, pars, 3, volume_num)
	call gspos ('DETI', 1,'DETE', 0., 0., 
	1		hpge_cover_depth / 2.,
	2		0, 'ONLY')
	call gsatt ('DETI', 'COLO', GREEN)	! Change color of the DETEctor
	call gsatt ('DETI', 'SEEN', 1)		! DETEctor is visible
	if (hpge_type .lt. 4.5) then
	  call gsdet ('EDET', 'DETI', 1, 'DETI', 32, 1, 10, 10, iset, idet)
	  call gsdeth('EDET', 'DETI', 1, names, nbits, orig, fact)
	endif

c add electron detector at exit from dipole 4

	call ugstmed (recoil_mate, 'recoil detector$', SILICON_MATE,
 	1	1, 0, FIELDM, TMAXFD, STEMAX, DEEMAX, EPSIL, 
 	2	STMIN, 0, 0)
	pars(1) = detector_width / 2.
	pars(2) = detector_height / 2.
	pars(3) = detector_thickness / 2.
	call ugsvolu('EDET', 'BOX ', recoil_mate, pars, 3, volume_num)
	pars(1) = 0.
	pars(2) = pars(2) + chicane_drop + detector_offset
	pars(3) = pars(3) + chicane_length / 2. + 0.5
	call gspos ('EDET', 1, mother, pars(1), pars(2), pars(3), 0, 'ONLY')
	call gsdvt ('EDES', 'EDET', detector_stripwidth, 2, recoil_mate,
 	1	int((detector_height+0.001)/detector_stripwidth))
	call gsatt ('EDET', 'COLO', RED)	! Change color of the detector
	call gsatt ('EDET', 'SEEN', 1)	! recoil detector is visible
	call gsdet ('EDET', 'EDES', 1, 'EDES', 32, 1, 10, 10, iset, idet)
	call gsdeth('EDET', 'EDES', 1, names, nbits, orig, fact)

	end
