	subroutine define_lattice (mother)

c This routine defines and places the dipoles for the Compton chicane.
c Inputs:
c	mother: 4-character name of outer volume in which magnets are placed
c
c PW 20-Oct-93
c  - original code
c
c DJG 16-Mar-2003
c  - commented out the quad in the middle of the straight section
c  - added dipoles for the chicane
c
c Richard Jones June 19, 2003
c  - got rid of "fortran structure" references in favour of standard f77
c  - replaced trig intrinsics based on degrees (sind,cosd,tand..) with
c    local versions because g77 does not support them
c  - Most of the geometry has now been rewritten.  The magnets are now
c    boxes (instead of tubes) composed of iron and having rectangular
c    slots through them for the beam to pass through.
c  - A problem appeared in the tracking of low-energy electrons in the
c    dipole gap in that they would spiral forever and waste time until
c    Geant would give up with a warning, "10000 steps, track abandoned".
c    To correct this, the media in strong magnetic fields are told to
c    stop tracking electrons below 1 MeV in kinetic energy.

	implicit none

	include 'user.inc'
	include 'params.inc'
	include 'ugeom.inc'

	character*(*) mother			! volume to imbed this one in
	integer volume_num, magnet_mate, beamline_mate
	real pars(9)

c Now define the quadrapole
C DJG: No quadrupole
C DJG	call ugstmed (magnet_mate, 'Dipole$', VACUUM_MATE,
C DJG	1		0, 1, dipole_field, TMAXFD, STEMAX, DEEMAX, EPSIL, 
C DJG	2		STMIN, 0, 0)
C DJG	pars(1) =  10.
C DJG	pars(2) =  20.
C DJG	pars(3) =  46. / 2.		! length of quad
C DJG	call ugsvolu ('QUAD', 'TUBE ', magnet_mate, pars, 3, volume_num)
C DJG	call gspos ('QUAD', 1, mother, 0., 0., 0., 0, 'ONLY')
C DJG	call gsatt ('QUAD', 'COLO', GREEN)	! Change color of the Quad
C DJG	call gsatt ('QUAD', 'SEEN', 1)		! Quad is visible

c Now define the chicane

	if (dipole_length .ne. 0.) then
	   if (event_type_brem .ne. 0) then
	      call ugstmed (beamline_mate, 'dipole vacuum$', MYVAC_MATE,
	1	   0, 1, dipole_field, TMAXFD, STEMAX, DEEMAX, EPSIL, 
	2	   STMIN, 0, 0)
	   else
	      call ugstmed (beamline_mate, 'dipole vacuum$', VACUUM_MATE,
	1	   0, 1, dipole_field, TMAXFD, STEMAX, DEEMAX, EPSIL, 
	2	   STMIN, 0, 0)
	   endif
	   call ugstmed (magnet_mate, 'dipole yoke$', IRON_MATE,
	1	0, 1, dipole_field, TMAXFD, STEMAX, DEEMAX, EPSIL, 
	2	STMIN, 0, 0)

c Stop electrons below 1 MeV, otherwise they curl up in the field
c and circle forever in the vacuum, using up cpu time and doing nothing

	  call gstpar (beamline_mate, 'CUTELE', 1e-3)
	  call gstpar (magnet_mate, 'CUTELE', 1e-3)

c Now define the dipole magnets

	  pars(1) = 20.
	  pars(2) = 40.
	  pars(3) = dipole_length / 2.
	  call ugsvolu ('DIPO', 'BOX  ', magnet_mate, pars, 3, volume_num)
	  pars(1) = 1.
	  pars(2) = 8.
	  call ugsvolu ('DIPI', 'BOX  ', beamline_mate, pars, 3, volume_num)
	  pars(2) = 2.5
	  call gspos ('DIPI', 1, 'DIPO', 0., pars(2), 0.,  0, 'ONLY')
	  call gsatt ('DIPO', 'COLO', BLUE)	! Change color of the dipole
	  call gsatt ('DIPO', 'SEEN', 1)	! dipole is visible

C DJG: First dipole
	  pars(2) = chicane_drop
	  pars(3) = -chicane_length / 2. + dipole_length / 2.
	  call gspos ('DIPO', 1, mother, 0., pars(2), pars(3), 1, 'ONLY')

C DJG: Second dipole
	  pars(2) = 0.0
	  pars(3) = -chicane_length / 2. + dipole_length / 2. + 
	1      chicane_drift + dipole_length
	  call gspos ('DIPO', 2, mother, 0., pars(2), pars(3), 2, 'ONLY')

C DJG: Third dipole
	  pars(2) = 0.0
	  pars(3) = -chicane_length / 2. + dipole_length / 2. + 
	1      chicane_drift + dipole_length + chicane_mid + dipole_length
	  call gspos ('DIPO', 3, mother, 0., pars(2), pars(3), 3, 'MANY')

C DJG: Fourth dipole
	  pars(2) = chicane_drop
	  pars(3) = -chicane_length / 2. + dipole_length / 2. + 
	1      chicane_drift + dipole_length + chicane_mid + dipole_length + 
	2      chicane_drift + dipole_length
	  call gspos ('DIPO', 4, mother, 0., pars(2), pars(3), 4, 'ONLY')
	endif

	end
