	subroutine gudigi

c This routine extracts the hits information from the Geant structures
c and saves the results in the form of hbook ntuples.
c
c PW 20-Oct-93
c  - original code
c
c Richard Jones June 19, 2003
c  - mostly rewritten, the old code was based on canned histograms and
c    relied on a confusing array of duplicate histograms with different
c    normalizations.
c  - The output from the simulation now appears in a series of ntuples
c    that correspond 1-1 to the flags in the input control TYPE card.
c  - One ntuple is produced in the output for each TYPE flag set.
c  - An active ntuple receives one entry for each event for which there
c    was at least one detector that saw a signal.
c  - The simulations for different ntuples employ different optimization
c    schemes to enhance the statistics for that process.  Each entry is
c    provided with weights that can be used to convert it to a normalized
c    rate in Hz.
c  - If the cross section for the production was distorted in the
c    generation phase, the factor wXSect is provided to correct it.
c  - The weight factor wLumin/N converts counts into physical rate (/s),
c    where N is the number of events in the simulation.
c  - For example, the following paw command,
c
c            paw> ntuple/plot 3.Egamma wXSect*xLumin/1e6
c
c    can be run on a simulation of 1,000,000 halo events to produce a
c    plot of the rate as a function of energy in the gamma counter.
 
	implicit none

#include "geant321/gclist.inc"
#include "geant321/gcnum.inc"

	include 'user.inc'

	integer MAX_HITS
	parameter (MAX_HITS=1024)

	integer ilook				! flag returned from glook
	integer nhits				! # of hits found in gfhits
	integer mhits				! # of hits found in shield
	real Esum(MAX_HITS)				! Energy sum from gfhits
	integer numbv(MAX_HITS)			! volume number for this hit
	integer tracks(MAX_HITS)		! track number for this hit
	integer numvs(10)			! volume numbers
	data numvs/10*0/
	integer i,j,it,id			! index variables
	integer particle_type			! primary particle type
	integer vertex_number			! which vertex
	real vertex(3),pvertex(3)		! vertex parameters
	real user(10)				! user parameters
	integer num_user			! # of user parameters
	real shield_energy			! energy deposited in the shield
	real total_energy			! energy deposited in detectors

	logical hexist
	external hexist

	integer NSHIELDS,NDETECTS
	parameter (NSHIELDS = 3)
	parameter (NDETECTS = 2)
	character*4 shield_names(NSHIELDS) /'DETF', 'DETS', 'DETC'/
	character*4 detect_names(NDETECTS)/'DETI', 'EDES'/

	call glook ('HITS', lprin, nprin, ilook)
	if (ilook .gt. 0) then
	  call gphits ('*', '*')
	endif

c First get the energy deposited in the suppression shield

	shield_energy = 0.
	do j = 1, NSHIELDS
	  call gfhits ('SDET', shield_names(j), 1, 1, 10, 0,   
	1		numvs, tracks, numbv, Esum, mhits)
	  do i = 1, mhits
	    shield_energy = shield_energy + Esum(i)
	  enddo
	enddo

c Now get the energy deposited in the energy measuring detectors

	do id = 1, 5
	  total_energy = 0.
	  Egamma = 0.
	  nstrips = 0
	  do it = 1, ntrack
	    call gfkine(it, vertex, pvertex, particle_type,
	1		vertex_number, user, num_user)
	    if (user(1) .eq. id) then
	      call gfhits ('EDET', detect_names(1), 1, 1, MAX_HITS, it,   
	1		numvs, tracks, numbv, Esum, nhits)
	      do i = 1, nhits
	        Egamma = Egamma + Esum(i)
	        total_energy = total_energy + Esum(i)
	      enddo
	      do j = 2, NDETECTS
	        call gfhits ('EDET', detect_names(j), 1, 1, MAX_HITS, it,
	1		numvs, tracks, numbv, Esum, nhits)
	        do i = 1, nhits
	          nstrips = nstrips + 1
	          strip(nstrips) = numbv(i)
	          Estrip(nstrips) = Esum(i)
	          total_energy = total_energy + Esum(i)
	        enddo
	      enddo
	      vertx(1) = vertex(1)
	      vertx(2) = vertex(2)
	      vertx(3) = vertex(3)
	      vertp(1) = pvertex(1)
	      vertp(2) = pvertex(2)
	      vertp(3) = pvertex(3)
	      wXSect   = user(2)
	      wLumin   = user(3)
	      apower   = user(4)
	    endif
	  enddo
	  if (hexist(id) .and. total_energy .ge. 1e-6) then
	    call hfnt(id)
	  endif
	enddo

	end
